<?php
/**
 * Hook handler base class for BlueSpice hook BSInsertMagicAjaxGetData
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * This file is part of BlueSpice MediaWiki
 * For further information visit https://bluespice.com
 *
 * @author     Peter Boehm <boehm@hallowelt.com>
 * @package    BlueSpiceInsertMagic
 * @copyright  Copyright (C) 2018 Hallo Welt! GmbH, All rights reserved.
 * @license    http://www.gnu.org/copyleft/gpl.html GPL-3.0-only
 * @filesource
 */
namespace BlueSpice\InsertMagic\Hook;

use BlueSpice\Hook;

abstract class BSInsertMagicAjaxGetData extends Hook {

	/**
	 * Holds data to be sent to client
	 * @var \stdClass
	 */
	protected $response = null;

	/**
	 * type of current process data for backwards compatibility
	 * @var string
	 */
	protected $type = null;

	/**
	 * Located in \BSApiInsertMagicDataStore::makeData. Collects magic words
	 * to be send to the client
	 * @param \stdClass &$response
	 * @param string $type
	 * @return bool
	 */
	public static function callback( &$response, $type ) {
		$className = static::class;
		$hookHandler = new $className(
			null,
			null,
			$response,
			$type
		);
		return $hookHandler->process();
	}

	/**
	 * @param \IContextSource $context
	 * @param \Config $config
	 * @param \stdClass &$response
	 * @param string $type
	 */
	public function __construct( $context, $config, &$response, $type ) {
		parent::__construct( $context, $config );

		$this->response = &$response;
		$this->type = $type;
	}
}
